@@ -9,7 +9,7 @@ from numpy.core.records import ndarray
 
 from mpl_format.axes.axis_formatter import AxisFormatter
 from mpl_format.axes.axis_utils import new_axes
-from mpl_format.compound_types import FontSize, Color, LegendLocation
+from mpl_format.compound_types import FontSize, Color, LegendLocation, FloatOrFloats, ArrayLike
 from mpl_format.io_utils import save_plot
 from mpl_format.legend.legend_formatter import LegendFormatter
 from mpl_format.text.text_formatter import TextFormatter
@@ -69,8 +69,8 @@ class AxesFormatter(object):
     @property
     def legend(self) -> LegendFormatter:
         """
-        Return a LegendFormatter for the legend of the wrapped Axes, if there is one.
-        :return:
+        Return a LegendFormatter for the legend of the wrapped Axes,
+        if there is one.
         """
         return self._legend
 
@@ -483,7 +483,9 @@ class AxesFormatter(object):
 
     # region spans
 
-    def add_h_line(self, y: float = 0, x_min: float = 0, x_max: float = 1,
+    def add_h_line(self, y: Union[float, str] = 0,
+                   x_min: Union[float, str] = 0,
+                   x_max: Union[float, str] = 1,
                    color: Optional[Color] = None,
                    alpha: Optional[float] = None,
                    line_style: Optional[str] = None,
@@ -526,7 +528,9 @@ class AxesFormatter(object):
         )
         return self
 
-    def add_v_line(self, x: float = 0, y_min: float = 0, y_max: float = 1,
+    def add_v_line(self, x: Union[float, str] = 0,
+                   y_min: Union[float, str] = 0,
+                   y_max: Union[float, str] = 1,
                    color: Optional[Color] = None, alpha: Optional[float] = None,
                    line_style: Optional[str] = None,
                    line_width: Optional[float] = None,
@@ -566,6 +570,116 @@ class AxesFormatter(object):
         )
         return self
 
+    def add_h_lines(self, y: FloatOrFloats,
+                    x_min: FloatOrFloats, x_max: FloatOrFloats,
+                    colors='k', line_styles: str = 'solid',
+                    label: Optional[str] = '') -> 'AxesFormatter':
+        """
+        Plot horizontal lines at each y from x_min to x_max.
+
+        :param y: x-indexes where to plot the lines.
+        :param x_min: Beginning of each or all lines.
+        :param x_max: End of each or all lines.
+        :param colors: Line colors.
+        :param line_styles: One of {'solid', 'dashed', 'dashdot', 'dotted'}
+        :param label: Label.
+        """
+        self._axes.hlines(y=y, xmin=x_min, xmax=x_max,
+                          colors=colors, linestyles=line_styles,
+                          label=label)
+        return self
+
+    def add_v_lines(self, x: FloatOrFloats,
+                    y_min: FloatOrFloats, y_max: FloatOrFloats,
+                    colors='k', line_styles: str = 'solid',
+                    label: Optional[str] = '') -> 'AxesFormatter':
+        """
+        Plot vertical lines at each x from y_min to y_max.
+
+        :param x: x-indexes where to plot the lines.
+        :param y_min: Beginning of each or all lines.
+        :param y_max: End of each or all lines.
+        :param colors: Line colors.
+        :param line_styles: One of {'solid', 'dashed', 'dashdot', 'dotted'}
+        :param label: Label.
+        """
+        self._axes.vlines(x=x, ymin=y_min, ymax=y_max,
+                          colors=colors, linestyles=line_styles,
+                          label=label)
+        return self
+
+    def fill_between(self, x: ArrayLike,
+                     y1: Union[float, ArrayLike],
+                     y2: Union[float, ArrayLike],
+                     where: Optional[ArrayLike] = None,
+                     interpolate: bool = False,
+                     step: Optional[str] = None,
+                     color: Optional[Color] = None,
+                     alpha: Optional[float] = None,
+                     line_style: Optional[str] = None,
+                     line_width: Optional[float] = None,
+                     edge_color: Optional[Color] = None,
+                     face_color: Optional[Color] = None) -> 'AxesFormatter':
+        """
+        Make filled polygons between two curves.
+
+        :param x: An N-length array of the x data.
+        :param y1: An N-length array (or scalar) of the y data.
+        :param y2: An N-length array (or scalar) of the y data.
+        :param where: If None, default to fill between everywhere. If not None,
+                      it is an N-length numpy boolean array and the fill will
+                      only happen over the regions where where==True.
+        :param interpolate: If True, interpolate between the two lines to find
+                            the precise point of intersection. Otherwise, the
+                            start and end points of the filled region will only
+                            occur on explicit values in the x array.
+        :param step: One of {‘pre’, ‘post’, ‘mid’}. If not None, fill with step
+                     logic.
+        :param color: matplotlib color arg or sequence of rgba tuples
+        :param alpha: Opacity.
+        :param line_style: One of {'-', '--', '-.', ':', ''}
+        :param line_width: float or sequence of floats
+        :param edge_color: matplotlib color spec or sequence of specs
+        :param face_color: matplotlib color spec or sequence of specs
+        """
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [color, alpha, line_style, line_width, edge_color, face_color],
+            ['color', 'alpha', 'line_style',
+             'line_width', 'edge_color', 'face_color']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+
+        self._axes.fill_between(
+            x=x, y1=y1, y2=y2,
+            where=where, interpolate=interpolate,
+            step=step,
+            **kwargs
+        )
+        return self
+
+    # endregion
+
+    # region colors
+
+    def set_face_color(self, color: Color) -> 'AxesFormatter':
+
+        self._axes.set_facecolor(color)
+        return self
+
+    def set_frame_color(self, color: Color) -> 'AxesFormatter':
+
+        for pos in ['top', 'bottom', 'right', 'left']:
+            self._axes.spines[pos].set_edgecolor(color)
+        return self
+
+    def set_tick_color(self, color: Color) -> 'AxesFormatter':
+
+        self.x_axis.set_tick_color(color=color)
+        self.y_axis.set_tick_color(color=color)
+        return self
+
     # endregion
 
     def set_title_font_family(self, font_name: str) -> 'AxesFormatter':
@@ -667,7 +781,7 @@ class AxesFormatter(object):
             font_properties: Optional[Union[FontProperties, dict]] = None,
             line_points: Optional[int] = None,
             scatter_points: Optional[int] = None,
-            scatter_y_offsets: Optional[ndarray] = None,
+            scatter_y_offsets: Optional[ArrayLike] = None,
             marker_scale: Optional[float] = None,
             frame_on: Optional[bool] = None,
             shadow: Optional[bool] = None,
